@@ -6,7 +6,7 @@ Cookieville - REST API for your database
 
 =head1 VERSION
 
-0.05
+0.06
 
 =head1 DESCRIPTION
 
@@ -103,7 +103,7 @@ Does a SELECT from the given C<source> with a given set of query params:
 
 =item * q=:json (mandatory)
 
-C<q> will be L<deserialized|Mojo::JSON/decode> and used as the
+C<q> will be L<deserialized|Mojo::JSON/decode_json> and used as the
 L<query part|/Queries>.
 
 =item * columns=:json (optional)
@@ -234,7 +234,7 @@ the first argument to L<DBIx::Class/search>.
 use Mojo::Base 'Mojolicious';
 use File::Spec ();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 ATTRIBUTES
 
@@ -292,7 +292,7 @@ Used to setup the L</RESOURCES>.
 
 sub setup_routes {
   my $self = shift;
-  my $r = $self->routes;
+  my $r    = $self->routes;
 
   if (my $rules = $self->config('access_rules')) {
     $self->plugin('Cookieville::Plugin::Authorize', $rules);
@@ -301,11 +301,13 @@ sub setup_routes {
 
   $self->routes->get('/')->to('schema#index')->name('cookieville') unless $r->find('cookieville');
   $r->get('/sources')->to('schema#sources_list')->name('schema_source_list') unless $r->find('schema_source_list');
-  $r->get('/:source/schema')->to('schema#source_schema')->name('schema_for_source') unless $r->find('schema_for_source');
-  $r->get('/:source/search')->to('read#search')->name('source_search') unless $r->find('source_search');
+  $r->get('/:source/schema')->to('schema#source_schema')->name('schema_for_source')
+    unless $r->find('schema_for_source');
+  $r->get('/:source/search')->to('read#search')->name('source_search')  unless $r->find('source_search');
   $r->delete('/:source/:id')->to('write#delete')->name('source_delete') unless $r->find('source_delete');
-  $r->patch('/:source/:id')->to('write#patch')->name('source_patch') unless $r->find('source_patch');
-  $r->put('/:source')->to('write#update_or_insert')->name('source_update_or_insert') unless $r->find('source_update_or_insert');
+  $r->patch('/:source/:id')->to('write#patch')->name('source_patch')    unless $r->find('source_patch');
+  $r->put('/:source')->to('write#update_or_insert')->name('source_update_or_insert')
+    unless $r->find('source_update_or_insert');
 }
 
 =head2 startup
@@ -331,16 +333,17 @@ sub startup {
     eval "require $schema_class;1" or die $@;
   }
 
-  $self->hook(before_dispatch => sub {
-    my $c = shift;
-    Mojo::IOLoop->stream($c->tx->connection)->timeout($self->inactive_timeout);
-  });
+  $self->hook(
+    before_dispatch => sub {
+      my $c = shift;
+      Mojo::IOLoop->stream($c->tx->connection)->timeout($self->inactive_timeout);
+    }
+  );
 
-  push @{ $self->renderer->classes }, __PACKAGE__;
+  push @{$self->renderer->classes}, __PACKAGE__;
   $self->defaults(format => 'json', message => '');
   $self->types->type(csv => 'text/csv');
-  $self->helper(db => sub { shift->stash->{db} ||= $self->schema_class->connect(@{ $self->connect_args }); });
-  $self->helper(j => sub { Mojo::JSON->new->encode($_[1]); });
+  $self->helper(db => sub { shift->stash->{db} ||= $self->schema_class->connect(@{$self->connect_args}); });
   $self->setup_routes;
 }
 
@@ -361,7 +364,8 @@ Jan Henning Thorsen - C<jhthorsen@cpan.org>
 
 __DATA__
 @@ not_authorized.json.ep
-%== j { message => $message || 'Not authorized.' }
+% use Mojo::JSON 'encode_json';
+%== encode_json { message => $message || 'Not authorized.' }
 @@ not_authorized.csv.ep
 %= $message || 'Not authorized.'
 @@ not_authorized.txt.ep
@@ -369,12 +373,14 @@ __DATA__
 @@ not_found.csv.ep
 %= $message || 'Not found.'
 @@ not_found.json.ep
-%== j { message => $message || 'Not found.' }
+% use Mojo::JSON 'encode_json';
+%== encode_json { message => $message || 'Not found.' }
 @@ not_found.txt.ep
 %= $message || 'Not found.'
 @@ exception.csv.ep
 %= $message || 'Internal server error.'
 @@ exception.json.ep
-%== j { message => $message || 'Internal server error.' }
+% use Mojo::JSON 'encode_json';
+%== encode_json { message => $message || 'Internal server error.' }
 @@ exception.txt.ep
 %= $message || 'Internal server error.'
