@@ -32,16 +32,15 @@ receive the error as a string. Example:
   use Mojolicious::Lite;
 
   get '/artists' => sub {
-    my $c = shift->render_later;
 
-    Mojo::IOLoop->delay(
+    $c->delay(
       sub {
         my ($delay) = @_;
         $c->cookieville_helper->search(Artist => {}, $delay->begin);
       },
       sub {
         my ($delay, $err, $res) = @_;
-        return $c->render_exception($err) if $err;
+        return $c->reply->exception($err) if $err;
         return $c->render(json => $res->{data});
       },
     );
@@ -50,7 +49,7 @@ receive the error as a string. Example:
 =cut
 
 use Mojo::Base -base;
-use Mojo::JSON 'j';
+use Mojo::JSON 'encode_json';
 use Mojo::UserAgent;
 use Mojo::URL;
 use Carp ();
@@ -114,7 +113,7 @@ sub delete {
   Scalar::Util::weaken($self);
   $self->_ua->delete(
     $self->_url("/$source/$id"),
-    { 'X-Cookieville-Auth-Id' => $self->id },
+    {'X-Cookieville-Auth-Id' => $self->id},
     sub { $self->$cb($self->_res_from_tx($_[1])); },
   );
 
@@ -140,10 +139,8 @@ sub patch {
 
   Scalar::Util::weaken($self);
   $self->_ua->patch(
-    $self->_url("/$source/$id"),
-    { 'X-Cookieville-Auth-Id' => $self->id },
-    j($data),
-    sub { $self->$cb($self->_res_from_tx($_[1])); },
+    $self->_url("/$source/$id"), {'X-Cookieville-Auth-Id' => $self->id},
+    encode_json($data), sub { $self->$cb($self->_res_from_tx($_[1])); },
   );
 
   return $self;
@@ -169,14 +166,12 @@ sub put {
 
   return $self->_blocking(put => $source, $data) unless ref $cb eq 'CODE';
   return $self->_abort('Invalid source.', $cb) unless $source;
-  return $self->_abort('Invalid data.', $cb) unless ref $data eq 'HASH';
+  return $self->_abort('Invalid data.',   $cb) unless ref $data eq 'HASH';
 
   Scalar::Util::weaken($self);
   $self->_ua->put(
-    $self->_url("/$source"),
-    { 'X-Cookieville-Auth-Id' => $self->id },
-    j($data),
-    sub { $self->$cb($self->_res_from_tx($_[1])); },
+    $self->_url("/$source"), {'X-Cookieville-Auth-Id' => $self->id},
+    encode_json($data), sub { $self->$cb($self->_res_from_tx($_[1])); },
   );
 
   return $self;
@@ -223,24 +218,24 @@ Sort the result by column(s). Examples:
 =cut
 
 sub search {
-  my $cb = ref $_[-1] eq 'CODE' ? pop : undef;
-  my $self = shift;
+  my $cb     = ref $_[-1] eq 'CODE' ? pop : undef;
+  my $self   = shift;
   my $source = shift;
-  my $query = shift;
-  my $extra = shift || {};
+  my $query  = shift;
+  my $extra  = shift || {};
 
   return $self->_blocking(search => $source, $query, $extra) unless ref $cb eq 'CODE';
   return $self->_abort('Invalid source.', $cb) unless $source;
-  return $self->_abort('Invalid query.', $cb) unless ref($query) =~ /HASH|ARRAY/;
+  return $self->_abort('Invalid query.',  $cb) unless ref($query) =~ /HASH|ARRAY/;
 
-  $extra->{columns} = j $extra->{columns} if $extra->{columns};
-  $extra->{order_by} = j $extra->{order_by} if $extra->{order_by};
-  $extra->{q} = j $query;
+  $extra->{columns}  = encode_json $extra->{columns}  if $extra->{columns};
+  $extra->{order_by} = encode_json $extra->{order_by} if $extra->{order_by};
+  $extra->{q}        = encode_json $query;
 
   Scalar::Util::weaken($self);
   $self->_ua->get(
     $self->_url("/$source/search")->query($extra),
-    { 'X-Cookieville-Auth-Id' => $self->id },
+    {'X-Cookieville-Auth-Id' => $self->id},
     sub { $self->$cb($self->_res_from_tx($_[1])); },
   );
 
@@ -251,11 +246,14 @@ sub _blocking {
   my ($self, $method, @args) = @_;
   my ($err, $res);
 
-  $self->$method(@args, sub {
-    my $self = shift;
-    ($err, $res) = @_;
-    $self->_ua->ioloop->stop;
-  });
+  $self->$method(
+    @args,
+    sub {
+      my $self = shift;
+      ($err, $res) = @_;
+      $self->_ua->ioloop->stop;
+    }
+  );
 
   $self->_ua->ioloop->start;
   Carp::confess($err) if $err;
